@@ -1,15 +1,18 @@
-from cqrs.compressors.protocol import Compressor
-from cqrs.compressors.zlib import ZlibCompressor
+from cqrs.compressors import Compressor, ZlibCompressor
 from cqrs.container.di import DIContainer
 from cqrs.container.protocol import Container
 from cqrs.events import EventMap
-from cqrs.events.event import DomainEvent, ECSTEvent, Event, NotificationEvent
+from cqrs.events.event import DomainEvent, Event, NotificationEvent
 from cqrs.events.event_emitter import EventEmitter
 from cqrs.events.event_handler import EventHandler, SyncEventHandler
 from cqrs.mediator import EventMediator, RequestMediator
-from cqrs.outbox.producer import EventProducer
+from cqrs.outbox.map import OutboxedEventMap
 from cqrs.outbox.repository import OutboxedEventRepository
-from cqrs.outbox.sqlalchemy import SqlAlchemyOutboxedEventRepository
+from cqrs.outbox.sqlalchemy import (
+    rebind_outbox_model,
+    SqlAlchemyOutboxedEventRepository,
+)
+from cqrs.producer import EventProducer
 from cqrs.requests import RequestMap
 from cqrs.requests.request import Request
 from cqrs.requests.request_handler import RequestHandler, SyncRequestHandler
@@ -20,11 +23,11 @@ __all__ = (
     "EventMediator",
     "DomainEvent",
     "NotificationEvent",
-    "ECSTEvent",
     "Event",
     "EventEmitter",
     "EventHandler",
     "EventMap",
+    "OutboxedEventMap",
     "SyncEventHandler",
     "Request",
     "RequestHandler",
@@ -34,8 +37,9 @@ __all__ = (
     "OutboxedEventRepository",
     "SqlAlchemyOutboxedEventRepository",
     "EventProducer",
-    "Compressor",
-    "ZlibCompressor",
     "Container",
     "DIContainer",
+    "Compressor",
+    "ZlibCompressor",
+    "rebind_outbox_model",
 )
